#!/bin/sh
# $Id: merge-changed-ids.sh 1 2007-06-04 12:47:41Z rea $
#
# Script to merge the changed 'Id' tags from the repository
# to the original file. We copy back (repo -> source) all files
# where only 'Id' tage were changed.

usage () {
	if test -n "$1"; then
		echo "Error: $1" > /dev/stderr
		echo > /dev/stderr
	fi
	cat > /dev/stderr << EOF
Usage: $0 filelist basedir

'filelist' specifies the source files, 'basedir' specifies the
location of the repository.
EOF
}

if test -z "$1"; then
	usage "missing first argument"
	exit 255
fi
if test -z "$2"; then
	usage "missing second argument"
	exit 255
fi

if ! test -f "$1"; then
	usage "'$1' is no a file"
	exit 255
fi
if ! test -d "$2"; then
	usage "'$1' is not a directory"
	exit 255
fi

sed -e'/^#/d' "$1" | while read orig; do
	repo="$2"/"$orig"
	if ! test -r "$repo"; then
		echo "File '$orig' is not in the repository. Skipping it."
		next
	fi
	diff "$orig" "$repo" > /dev/null
	code1="$?"
	diff -I '$Id.*$' "$orig" "$repo" > /dev/null
	code2="$?"
	if test "$code2" -eq 0; then
		if test "$code1" -ne 0; then
			echo "Merging '$orig'"
			cp "$repo" "$orig"
		fi
	else
		echo "File '$orig' differs from the repository's one."
	fi
done
